@@ -2,120 +2,10 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 C
 C   Perform one iteration in local constant  aws (gridded)
 C
-CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
-      subroutine mawsimg(y,fix,mask,n1,n2,dv,hakt,lambda,theta,bi,
-     1       bi0,thnew,kern,spmin,lw,wght,swjy)
-C   
-C   y        observed values of regression function
-C   n1,n2,n3    design dimensions
-C   hakt     actual bandwidth
-C   lambda   lambda or lambda*sigma2 for Gaussian models
-C   theta    estimates from last step   (input)
-C   bi       \sum  Wi   (output)
-C   thnew       \sum  Wi Y     (output)
-C   kern     specifies the location kernel
-C   wght     scaling factor for second and third dimension (larger values shrink)
-C   
-      implicit logical (a-z)
-      external kldistd,lkern
-      double precision kldistd,lkern
-      integer n1,n2,dv,kern,y(dv,n1,n2),theta(dv,n1,n2),
-     1        thnew(dv,n1,n2)
-      logical aws,fix(n1,n2),mask(n1,n2)
-      double precision bi(n1,n2),bi0,lambda,spmin,wght(dv),hakt,lw(*)
-      integer ih,ih1,i1,i2,j1,j2,k,n,
-     1        jind,jind2,jwind2,dlw,clw,jw1,jw2,thrednr
-      double precision bii,sij,swj,swj0,swjy(dv,*),z1,z2,wj,hakt2,bii0,
-     1        spf
-!$      integer omp_get_thread_num
-!$      external omp_get_thread_num
-      hakt2=hakt*hakt
-      spf=1.d0/(1.d0-spmin)
-      ih=int(hakt)
-      dlw=2*ih+1
-      clw=ih+1
-      aws=lambda.lt.1d40
-      n=n1*n2
-      bii0=bi0
-      swj0=0.d0
-C   compute location weights first
-      DO j2=1,dlw
-         z2=clw-j2
-         z2=z2*z2
-         ih1=int(sqrt(hakt2-z2))
-         jind2=(j2-1)*dlw
-         DO j1=clw-ih1,clw+ih1
-C  first stochastic term
-            jind=j1+jind2
-            z1=clw-j1
-            wj=lkern(kern,(z1*z1+z2)/hakt2)
-            swj0=swj0+wj
-            lw(jind)=wj
-         END DO
-      END DO
-      bi0=swj0
-      thrednr=1
-      call rchkusr()
-C$OMP PARALLEL DEFAULT(NONE)
-C$OMP& SHARED(n1,n2,dv,kern,y,theta,thnew,fix,mask,bi,bi0,lambda,
-C$OMP& spmin,wght,hakt,lw,swjy)
-C$OMP& FIRSTPRIVATE(hakt2,dlw,clw,ih,aws,n,bii0,spf)
-C$OMP& PRIVATE(ih1,i1,i2,j1,j2,k,jind,jind2,jwind2,jw1,jw2,
-C$OMP& bii,sij,swj,swj0,z1,z2,wj,thrednr)
-C$OMP DO SCHEDULE(GUIDED)
-      DO i2=1,n2
-!$         thrednr = omp_get_thread_num()
-         DO i1=1,n1
-C            iind=i1+(i2-1)*n1
-            IF (fix(i1,i2)) CYCLE
-C    nothing to do, final estimate is already fixed by control 
-            bii=bi(i1,i2)/lambda
-C   scaling of sij outside the loop
-            swj=0.d0
-            DO k=1,dv
-               swjy(k,thrednr)=0.d0
-            END DO
-            DO jw2=1,dlw
-               j2=jw2-clw+i2
-               if(j2.lt.1.or.j2.gt.n2) CYCLE
-               jwind2=(jw2-1)*dlw
-               z2=clw-jw2
-               ih1=int(sqrt(hakt2-z2*z2))
-               DO jw1=clw-ih1,clw+ih1
-                  j1=jw1-clw+i1
-                  if(j1.lt.1.or.j1.gt.n1) CYCLE
-                  if(.not.mask(j1,j2)) CYCLE
-                  wj=lw(jw1+jwind2)
-                  IF (aws) THEN
-              sij=bii*kldistd(theta(1,i1,i2),theta(1,j1,j2),1,wght,dv)
-                     IF (sij.gt.1.d0) CYCLE
-                        wj=wj*(1.d0-sij)
-                  END IF
-                  swj=swj+wj
-                  DO k=1,dv
-                     swjy(k,thrednr)=swjy(k,thrednr)+wj*y(k,j1,j2)
-                  END DO
-               END DO
-            END DO
-            DO k=1,dv
-               thnew(k,i1,i2)=int(swjy(k,thrednr)/swj)
-            END DO
-            bi(i1,i2)=swj
-         END DO
-      END DO
-C$OMP END DO NOWAIT
-C$OMP END PARALLEL
-C$OMP FLUSH(bi,thnew)
-      RETURN
-      END
-CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
-C
-C   Perform one iteration in local constant  aws (gridded)
-C
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       subroutine mawsimg0(y,fix,mask,n1,n2,dv,hakt,lambda,theta,bi,
      1       bi0,thnew,kern,spmin,lw,wght)
-C   
+C
 C   y        observed values of regression function
 C   n1,n2,n3    design dimensions
 C   hakt     actual bandwidth
@@ -125,8 +15,8 @@ C   bi       \sum  Wi   (output)
 C   thnew       \sum  Wi Y     (output)
 C   kern     specifies the location kernel
 C   wght     scaling factor for second and third dimension (larger values shrink)
-C   
-      implicit logical (a-z)
+C
+      implicit none
       external kldistd,lkern
       double precision kldistd,lkern
       integer n1,n2,dv,kern,y(dv,n1,n2),theta(dv,n1,n2),
@@ -173,7 +63,7 @@ C$OMP DO SCHEDULE(GUIDED)
          DO i1=1,n1
 C            iind=i1+(i2-1)*n1
             IF (fix(i1,i2)) CYCLE
-C    nothing to do, final estimate is already fixed by control 
+C    nothing to do, final estimate is already fixed by control
             bii=bi(i1,i2)/lambda
 C   scaling of sij outside the loop
             swj=0.d0
@@ -228,7 +118,7 @@ C   thnew    non-adaptive estimates    (output)
 C   kern     specifies the location kernel
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
-      implicit logical (a-z)
+      implicit none
       external kldistd,lkern
       double precision kldistd,lkern
       integer n1,n2,dv,kern,y(n1,n2,dv),thnew(n1,n2,dv)
@@ -292,7 +182,7 @@ C
 C   Compute nonadaptive kernel estimate
 C
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
-      subroutine awsimg0(y,n1,n2,dv,hakt,thnew,bi,kern,lw)
+      subroutine awsimg0(y,n1,n2,dv,hakt,thnew,bi,kern,lw,swjy)
 C
 C   y        observed values of regression function
 C   n1,n2,n3    design dimensions
@@ -302,16 +192,18 @@ C   thnew    non-adaptive estimates    (output)
 C   kern     specifies the location kernel
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
-      implicit logical (a-z)
+      implicit none
       external kldistd,lkern
       double precision kldistd,lkern
       integer n1,n2,dv,kern,y(dv,n1,n2),thnew(dv,n1,n2)
-      double precision bi(n1,n2),hakt,lw(*)
-      integer ih,ih1,ii,i1,i2,j1,j2,k,n,
+      double precision bi(n1,n2),hakt,lw(*),swjy(dv,*)
+      integer ih,ih1,ii,i1,i2,j1,j2,k,n,thrednr,
      1        jind,jind2,jwind2,dlw,clw,jw1,jw2
-      double precision swj,swj0,swjy(3),z1,z2,wj,hakt2
+      double precision swj,swj0,z1,z2,wj,hakt2
+!$      integer omp_get_thread_num
+!$      external omp_get_thread_num
       hakt2=hakt*hakt
-      ih=int(hakt)
+      ih=FLOOR(hakt)
       dlw=2*ih+1
       clw=ih+1
       n=n1*n2
@@ -319,7 +211,7 @@ C
       DO j2=1,dlw
          z2=clw-j2
          z2=z2*z2
-         ih1=int(sqrt(hakt2-z2))
+         ih1=FLOOR(sqrt(hakt2-z2))
          jind2=(j2-1)*dlw
          DO j1=clw-ih1,clw+ih1
             jind=j1+jind2
@@ -331,40 +223,41 @@ C
       END DO
       call rchkusr()
 C$OMP PARALLEL DEFAULT(NONE)
-C$OMP& SHARED(n1,n2,dv,kern,y,thnew,bi,hakt,lw,swj0)
-C$OMP& FIRSTPRIVATE(dlw,clw,ih,n,hakt2)
-C$OMP& PRIVATE(ii,ih1,i1,i2,j1,j2,k,jind,jind2,jwind2,jw1,
-C$OMP&         jw2,swj,swjy,z1,z2,wj)
+C$OMP& SHARED(n1,n2,dv,kern,y,thnew,bi,hakt,lw,swj0,swjy,clw,dlw,
+C$OMP&        ih,n,hakt2,z1,jind,jind2)
+C$OMP& PRIVATE(ii,ih1,i1,i2,j1,j2,k,jwind2,jw1,
+C$OMP&         jw2,swj,z2,wj,thrednr)
 C$OMP DO SCHEDULE(GUIDED)
       DO ii=1,n1*n2
+!$         thrednr = omp_get_thread_num()+1
          i1=mod(ii,n1)
          if(i1.eq.0) i1=n1
-         i2=(ii-i1)/n1+1          
-            swj=0.d0
-            DO k=1,dv
-               swjy(k)=0.d0
-            END DO
-            DO jw2=1,dlw
-               j2=jw2-clw+i2
-               if(j2.lt.1.or.j2.gt.n2) CYCLE
-               jwind2=(jw2-1)*dlw
-               z2=clw-jw2
-               ih1=int(sqrt(hakt2-z2*z2))
-               DO jw1=clw-ih1,clw+ih1
-                  j1=jw1-clw+i1
-                  if(j1.lt.1.or.j1.gt.n1) CYCLE
-                  wj=lw(jw1+jwind2)
-                  swj=swj+wj
-                  DO k=1,dv
-                     swjy(k)=swjy(k)+wj*y(k,j1,j2)
-                  END DO
+         i2=(ii-i1)/n1+1
+         swj=0.d0
+         DO k=1,dv
+            swjy(k,thrednr)=0.d0
+         END DO
+         DO jw2=1,dlw
+            j2=jw2-clw+i2
+            if(j2.lt.1.or.j2.gt.n2) CYCLE
+            jwind2=(jw2-1)*dlw
+            z2=clw-jw2
+            z2=z2*z2
+            ih1=FLOOR(sqrt(hakt2-z2))
+            DO jw1=clw-ih1,clw+ih1
+               j1=jw1-clw+i1
+               if(j1.lt.1.or.j1.gt.n1) CYCLE
+               wj=lw(jw1+jwind2)
+               swj=swj+wj
+               DO k=1,dv
+                  swjy(k,thrednr)=swjy(k,thrednr)+wj*y(k,j1,j2)
                END DO
             END DO
-            DO k=1,dv
-               thnew(k,i1,i2)=int(swjy(k)/swj)
-            END DO
-            bi(i1,i2)=swj
-            call rchkusr()
+         END DO
+         DO k=1,dv
+            thnew(k,i1,i2)=FLOOR(swjy(k,thrednr)/swj)
+         END DO
+         bi(i1,i2)=swj
       END DO
 C$OMP END DO NOWAIT
 C$OMP END PARALLEL
@@ -390,7 +283,7 @@ C   thnew       \sum  Wi Y     (output)
 C   kern     specifies the location kernel
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
-      implicit logical (a-z)
+      implicit none
       external kldistgc,lkern
       double precision kldistgc,lkern
       integer n,n1,n2,dv,kern,nvpar,y(dv,n1,n2),theta(dv,n1,n2),
@@ -437,7 +330,7 @@ C  first location weight
       bi0=swj0
       call rchkusr()
 C$OMP PARALLEL DEFAULT(NONE)
-C$OMP& SHARED(n1,n2,dv,dv2,kern,nvpar,y,theta,thnew,fix,early,homogen,
+C$OMP& SHARED(n1,n2,dv,kern,nvpar,y,theta,thnew,fix,early,homogen,
 C$OMP&        bi,lambda,spmin,hakt,lw,wghts,vcoef,chcorr,meanvar,
 C$OMP&        hhom,bi0,dlw,clw,n)
 C$OMP& FIRSTPRIVATE(aws,ih,hnfix,hakt2,spf,swj0,fixi,hmax2)
@@ -449,7 +342,7 @@ C$OMP DO SCHEDULE(GUIDED)
          hhomi=1.d0
          i1=mod(ii,n1)
          if(i1.eq.0) i1=n1
-         i2=(ii-i1)/n1+1          
+         i2=(ii-i1)/n1+1
          if(early) fixi=fix(ii)
          if(fixi) THEN
             DO k=1,dv
@@ -470,10 +363,10 @@ C   scaling of sij outside the loop
             swjy(k)=0.d0
             thi(k)=theta(k,i1,i2)
             si(k) = vcoef(1,k)
-            if(nvpar.gt.1) THEN 
+            if(nvpar.gt.1) THEN
                si(k) = si(k) + vcoef(2,k) * thi(k)
             END IF
-            if(nvpar.gt.2) THEN 
+            if(nvpar.gt.2) THEN
                si(k) = si(k) + vcoef(3,k) * thi(k) * thi(k)
             END IF
             si(k) = sqrt(max(si(k),0.1*meanvar(k)))
@@ -529,7 +422,7 @@ C  Now fill estimated Covariancematrix in pixel i
                   IF (sij.gt.spmin) THEN
                      wj=wj*(1.d0-spf*(sij-spmin))
                      if(homogen) hhommax=min(hhommax,z1)
-                  END IF 
+                  END IF
                END IF
                swj=swj+wj
                DO k=1,dv
@@ -553,194 +446,6 @@ C$OMP FLUSH(bi,thnew,fix,hhom)
       END
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 C
-C   Perform one iteration in local constant three-variate aws (gridded)
-C
-CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
-      subroutine awsvimg(y,fix,n1,n2,n,dv,vcoef,nvpar,meanvar,chcorr,
-     1                   hakt,hhom,lambda,theta,bi,bi0,thnew,kern,
-     2                   spmin,wghts,lw,swjy,early,homogen,dv2,thi,
-     3                   thij,si,s2i)
-C
-C   y        observed values of regression function
-C   n1,n2,n3    design dimensions
-C   hakt     actual bandwidth
-C   lambda   lambda or lambda*sigma2 for Gaussian models
-C   theta    estimates from last step   (input)
-C   bi       \sum  Wi   (output)
-C   thnew       \sum  Wi Y     (output)
-C   kern     specifies the location kernel
-C   wght     scaling factor for second and third dimension (larger values shrink)
-C
-      implicit logical (a-z)
-      external kldistgc,lkern
-      double precision kldistgc,lkern
-      integer n,n1,n2,dv,dv2,kern,nvpar,y(dv,n1,n2),theta(dv,n1,n2),
-     1        thnew(dv,n1,n2)
-      logical aws,fix(n),early,homogen,fixi
-      double precision bi(n),lambda,spmin,hakt,lw(*),wghts(dv),bi0,
-     1       vcoef(nvpar,dv),chcorr(*),meanvar(dv),hhom(n),
-     2       thi(dv,*),thij(dv,*),si(dv,*),s2i(dv2,*),swjy(dv,*)
-      integer ih,ih1,ii,i1,i2,j1,j2,ja1,je1,l,k,info,kdv,
-     1        jind,jind2,jwind2,dlw,clw,jw1,jw2,m0,thrednr
-      double precision bii,sij,swj,z1,z2,wj,hakt2,spf,
-     1       swj0,hhomi,hhommax,hfixmax,hnfix,hmax2
-!$      integer omp_get_thread_num
-!$      external omp_get_thread_num
-C  s2i, s2ii temporay stor sigma^2_i and its inverse (nneded for KL-distance)
-C  maximaum dv = 4
-      hakt2=hakt*hakt
-      hnfix=max(2.d0,6.d0-hakt)
-      spf=1.d0/(1.d0-spmin)
-      ih=int(hakt)
-      dlw=2*ih+1
-      clw=ih+1
-      aws=lambda.lt.1d40
-C      n=n1*n2
-C   compute location weights first
-      swj0=0.d0
-      fixi=.FALSE.
-      hmax2=0.d0
-      DO j2=1,dlw
-         z2=clw-j2
-         z2=z2*z2
-         ih1=int(sqrt(hakt2-z2))
-         ja1=max(1,clw-ih1)
-         je1=min(dlw,clw+ih1)
-         jind2=(j2-1)*dlw
-         DO j1=ja1,je1
-C  first location weight
-            jind=j1+jind2
-            z1=clw-j1
-            wj=lkern(kern,(z1*z1+z2)/hakt2)
-            if(wj.gt.0) hmax2=max(hmax2,z1*z1+z2)
-            swj0=swj0+wj
-            lw(jind)=wj
-         END DO
-      END DO
-      bi0=swj0
-      thrednr=1
-      call rchkusr()
-C$OMP PARALLEL DEFAULT(NONE)
-C$OMP& SHARED(n1,n2,dv,dv2,kern,nvpar,y,theta,thnew,fix,early,homogen,
-C$OMP&        bi,lambda,spmin,hakt,lw,wghts,vcoef,chcorr,meanvar,
-C$OMP&        hhom,thi,thij,si,s2i,swjy,bi0,dlw,clw,n)
-C$OMP& FIRSTPRIVATE(aws,ih,hnfix,hakt2,spf,swj0,fixi,hmax2)
-C$OMP& PRIVATE(ii,ih1,i1,i2,j1,j2,ja1,je1,l,k,info,kdv,jind,jind2,
-C$OMP&         jwind2,jw1,jw2,m0,bii,sij,swj,z1,z2,wj,hhommax,hfixmax,
-C$OMP&         thrednr,hhomi)
-C$OMP DO SCHEDULE(GUIDED)
-      DO ii=1,n1*n2
-!$         thrednr = omp_get_thread_num()+1
-         hhomi=1.d0
-         i1=mod(ii,n1)
-         if(i1.eq.0) i1=n1
-         i2=(ii-i1)/n1+1          
-         if(early) fixi=fix(ii)
-         if(fixi) THEN
-            DO k=1,dv
-               thnew(k,i1,i2)=theta(k,i1,i2)
-            END DO
-            CYCLE
-         END IF
-         if(homogen) THEN
-            hhomi=hhom(ii)
-            hhomi=hhomi*hhomi
-         END IF
-         hhommax=hmax2
-         hfixmax=hhomi
-         bii=bi(ii)/lambda
-C   scaling of sij outside the loop
-         swj=0.d0
-         DO k=1,dv
-            swjy(k,thrednr)=0.d0
-            thi(k,thrednr)=theta(k,i1,i2)
-            si(k,thrednr) = vcoef(1,k)
-            if(nvpar.gt.1) THEN 
-               si(k,thrednr) = si(k,thrednr) + vcoef(2,k) * 
-     1                                            thi(k,thrednr)
-            END IF
-            if(nvpar.gt.2) THEN 
-               si(k,thrednr) = si(k,thrednr) + vcoef(3,k) * 
-     1                               thi(k,thrednr) * thi(k,thrednr)
-            END IF
-            si(k,thrednr) = sqrt(max(si(k,thrednr),0.1*meanvar(k)))
-C set small variances to  0.1 * mean variance
-         END DO
-C  Now fill estimated Covariancematrix in pixel i
-         m0=1
-         DO k=1,dv
-            kdv = (k-1)*dv
-            DO l=1,k
-               s2i(l+kdv,thrednr)=si(k,thrednr)*si(l,thrednr)/
-     1                                   wghts(k)/wghts(l)
-               if(l.ne.k) THEN
-                  s2i(l+kdv,thrednr)=s2i(l+kdv,thrednr)*chcorr(m0)
-                  m0=m0+1
-               END IF
-            END DO
-         END DO
-         call dpotrf("U",dv,s2i(1,thrednr),dv,info)
-         IF (info.ne.0) call intpr("non-definite matrix 1",21,info,1)
-         call dpotri("U",dv,s2i(1,thrednr),dv,info)
-         IF (info.ne.0) call intpr("non-definite matrix 2",21,info,1)
-         IF(dv.gt.1) THEN
-            DO k=2,dv
-               kdv = (k-1)*dv
-               DO l=1,k-1
-                  s2i(k+(l-1)*dv,thrednr)=s2i(l+kdv,thrednr)
-               END DO
-            END DO
-         END IF
-         DO jw2=1,dlw
-            j2=jw2-clw+i2
-            if(j2.lt.1.or.j2.gt.n2) CYCLE
-            jwind2=(jw2-1)*dlw
-            z2=clw-jw2
-            z2=z2*z2
-            ih1=int(sqrt(hakt2-z2))
-            DO jw1=clw-ih1,clw+ih1
-               j1=jw1-clw+i1
-               if(j1.lt.1.or.j1.gt.n1) CYCLE
-               z1=clw-jw1
-               z1=z1*z1+z2
-               DO k=1,dv
-                  thij(k,thrednr)=thi(k,thrednr)-theta(k,j1,j2)
-               END DO
-               wj=lw(jw1+jwind2)
-               IF (aws.and.z1.ge.hhomi) THEN
-                  sij=bii*kldistgc(thij(1,thrednr),s2i(1,thrednr),dv)
-                  IF (sij.gt.1.d0) THEN
-                     if(homogen) hhommax=min(hhommax,z1)
-                     CYCLE
-                  END IF
-                  if(early) hfixmax=max(hfixmax,z1)
-                  IF (sij.gt.spmin) THEN
-                     wj=wj*(1.d0-spf*(sij-spmin))
-                     if(homogen) hhommax=min(hhommax,z1)
-                  END IF 
-               END IF
-               swj=swj+wj
-               DO k=1,dv
-                  swjy(k,thrednr)=swjy(k,thrednr)+wj*y(k,j1,j2)
-               END DO
-            END DO
-         END DO
-         DO k=1,dv
-            thnew(k,i1,i2)=int(swjy(k,thrednr)/swj)
-         END DO
-         bi(ii)=swj
-         if(homogen) hhom(ii)=sqrt(hhommax)
-         IF(early.and.hakt-sqrt(hfixmax).ge.hnfix) THEN
-            fix(ii)=.TRUE.
-         END IF
-      END DO
-C$OMP END DO NOWAIT
-C$OMP END PARALLEL
-C$OMP FLUSH(bi,thnew,fix,hhom)
-      RETURN
-      END
-CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
-C
 C
 C          Compute Location Kernel (Compact support only, based on x^2
 C                                   ignores scaling)
@@ -752,7 +457,7 @@ C          Kern=4     Triweight
 C
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       double precision function lkern(kern,xsq)
-      implicit logical (a-z)
+      implicit none
       integer kern
       double precision xsq,z
       IF (xsq.ge.1) THEN
@@ -776,19 +481,19 @@ C   Plateau
 C        use Epanechnikov
          lkern=1.d0-xsq
       ENDIF
-      RETURN 
-      END   
+      RETURN
+      END
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 C
 C
 C          Compute the Kullback-Leibler Distance
 C
-C          Gaussian   
+C          Gaussian
 C
 C
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       double precision function kldistgc(thij,s2ii,dv)
-      implicit logical (a-z)
+      implicit none
       integer k,l,dv
       double precision thij(dv),s2ii(dv,dv),z,thijk
       z= thij(1)*thij(1)*s2ii(1,1)
@@ -814,7 +519,7 @@ C
 C
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       double precision function kldistd(thi,thj,n,wght,nwght)
-      implicit logical (a-z)
+      implicit none
       integer n,nwght,i,k,thi(*),thj(*)
       double precision z,wght(nwght)
       kldistd=0.d0
@@ -826,7 +531,7 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       END DO
       RETURN
       END
-CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC 
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 C
 C
 C    Estimate variance parameters
@@ -834,7 +539,7 @@ C
 C
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       subroutine esigmac(y,n,dv,theta,bi,quant,varcoef,mvar)
-      implicit logical (a-z)
+      implicit none
       integer n,dv,y(n,dv),theta(n,dv),quant(dv)
       double precision bi(n),varcoef(dv),mvar(dv)
       integer i,k
@@ -842,7 +547,7 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       DO k=1,dv
          sumres=0.d0
          sumwght=0.d0
-C$OMP PARALLEL DO 
+C$OMP PARALLEL DO
 C$OMP& DEFAULT(SHARED)
 C$OMP& PRIVATE(i,bii,res,wght)
 C$OMP& REDUCTION(+:sumres,sumwght)
@@ -867,7 +572,7 @@ C$OMP END PARALLEL DO
       RETURN
       END
       subroutine esigmal(y,n,dv,theta,bi,quant,varcoef,mvar)
-      implicit logical (a-z)
+      implicit none
       integer n,dv,y(n,dv),theta(n,dv),quant(dv)
       double precision bi(n),varcoef(2,dv),mvar(dv),res
       integer i,k
@@ -912,7 +617,7 @@ C$OMP END PARALLEL DO
       RETURN
       END
       subroutine esigmaq(y,n,dv,theta,bi,quant,varcoef,mvar)
-      implicit logical (a-z)
+      implicit none
       integer n,dv,y(n,dv),theta(n,dv),quant(dv)
       double precision bi(n),varcoef(3,dv),mvar(dv),res,mat(3,3),
      1        imat(3,3)
@@ -978,8 +683,8 @@ C    if info>0 just keep the old estimate
              varcoef(2,k)=0d0
              varcoef(3,k)=0d0
              mvar(k)=1d-2
-             CYCLE  
-         END IF 
+             CYCLE
+         END IF
          tt(1)=t0
          tt(2)=t1
          tt(3)=t2
@@ -993,7 +698,7 @@ C    if info>0 just keep the old estimate
       RETURN
       END
       subroutine estcorr(res,n1,n2,dv,scorr,chcorr)
-      implicit logical (a-z)
+      implicit none
       integer n1,n2,dv
       double precision res(n1,n2,dv),scorr(2,dv),chcorr(1)
       integer i,j,k,n,m,l
